import Vue from 'vue';
import Vuex from 'vuex';
import {Aid} from "@/model/Aid";
import {Quarter} from "@/model/Quarter";
import {Month} from "@/model/Month";

import authStore from "@/store/AuthStore";
import citizenStore from "@/store/CitizenStore";
import probabilityStore from "@/store/ProbabilityStore";
import argumentStore from "@/store/ArgumentStore";
import trainingPlanStore from "@/store/TrainingPlanStore";
import aidStore from "@/store/AidStore";
import registeredFallStore from "@/store/RegisteredFallStore";
import diagnosesStore from "@/store/DiagnosesStore";
import motivationStore from "@/store/MotivationStore";

Vue.use(Vuex)

export default new Vuex.Store({
    state: {
        quarters: [
            new Quarter(2018, 1,
                new Month(0, 5, new Date(2018, 0)),
                new Month(0, 5, new Date(2018, 1)),
                new Month(0, 5, new Date(2018, 2))
            ),
            new Quarter(2018, 2,
                new Month(0, 8, new Date(2018, 3)),
                new Month(0, 8, new Date(2018, 4)),
                new Month(0, 8, new Date(2018, 5))
            ),
            new Quarter(2018, 3,
                new Month(0, 8, new Date(2018, 6)),
                new Month(0, 10, new Date(2018, 7)),
                new Month(0, 10, new Date(2018, 8))
            ),
            new Quarter(2018, 4,
                new Month(0, 10, new Date(2018, 9)),
                new Month(0, 10, new Date(2018, 10)),
                new Month(0, 10, new Date(2018, 11))
            ),
            new Quarter(2019, 1,
                new Month(0, 10, new Date(2019, 0)),
                new Month(0, 10, new Date(2019, 1)),
                new Month(0, 15, new Date(2019, 2))
            ),
            new Quarter(2019, 2,
                new Month(0, 15, new Date(2019, 3)),
                new Month(0, 15, new Date(2019, 4)),
                new Month(0, 15, new Date(2019, 5))
            ),
            new Quarter(2019, 3,
                new Month(0, 10, new Date(2019, 6)),
                new Month(0, 10, new Date(2019, 7)),
                new Month(0, 10, new Date(2019, 8))
            ),
            new Quarter(2019, 4,
                new Month(0, 10, new Date(2019, 9)),
                new Month(0, 20, new Date(2019, 10)),
                new Month(0, 20, new Date(2019, 11))
            ),
            new Quarter(2020, 1,
                new Month(0, 20, new Date(2020, 0)),
                new Month(0, 20, new Date(2020, 1)),
                new Month(0, 20, new Date(2020, 2))
            ),
            new Quarter(2020, 2,
                new Month(0, 20, new Date(2020, 3)),
                new Month(0, 20, new Date(2020, 4)),
                new Month(0, 20, new Date(2020, 5))
            ),
            new Quarter(2020, 3,
                new Month(0, 20, new Date(2020, 6)),
                new Month(0, 20, new Date(2020, 7)),
                new Month(0, 20, new Date(2020, 8))
            ),
            new Quarter(2020, 4,
                new Month(0, 20, new Date(2020, 9)),
                new Month(0, 20, new Date(2020, 10)),
                new Month(0, 20, new Date(2020, 11))
            ),

        ]
    },
    mutations: {},
    actions: {},
    getters: {
        quarters: (state, rootGetters) => {
            let quarters = state.quarters
            let aids: Aid[] = rootGetters.activeAids

            quarters.forEach(value => {
                value.month1.aids = aids.filter((x: Aid) => x.dateReceived < new Date(value.year, value.month1.date.getMonth())).length
                value.month2.aids = aids.filter((x: Aid) => x.dateReceived < new Date(value.year, value.month2.date.getMonth())).length
                value.month3.aids = aids.filter((x: Aid) => x.dateReceived < new Date(value.year, value.month3.date.getMonth())).length
            })
            return quarters
        },
    },
    modules: {
        authStore,
        citizenStore,
        probabilityStore,
        argumentStore,
        trainingPlanStore,
        aidStore,
        registeredFallStore,
        diagnosesStore,
        motivationStore
    }
})
